@@ -5,7 +5,7 @@ use warnings;
 package Sub::HandlesVia::HandlerLibrary::Number;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.015';
+our $VERSION   = '0.017';
 
 use Sub::HandlesVia::HandlerLibrary;
 our @ISA = 'Sub::HandlesVia::HandlerLibrary';
@@ -13,7 +13,7 @@ our @ISA = 'Sub::HandlesVia::HandlerLibrary';
 use Sub::HandlesVia::Handler qw( handler );
 use Types::Standard qw( Num Any Item Defined );
 
-our @METHODS = qw( set get add sub mul div mod abs );
+our @METHODS = qw( set get add sub mul div mod abs cmp eq ne gt lt ge le );
 
 sub _type_inspector {
 	my ($me, $type) = @_;
@@ -90,4 +90,27 @@ sub abs {
 		additional_validation => 'no incoming values',
 }
 
+for my $comparison ( qw/ cmp eq ne lt gt le ge / ) {
+	my $op = {
+		cmp => '<=>',
+		eq  => '==',
+		ne  => '!=',
+		lt  => '<',
+		gt  => '>',
+		le  => '<=',
+		ge  => '>=',
+	}->{$comparison};
+
+	no strict 'refs';
+	*$comparison = sub {
+		handler
+			name      => "Number:$comparison",
+			args      => 1,
+			signature => [Num],
+			usage     => '$num',
+			template  => "\$GET $op \$ARG",
+	};
+}
+
+
 1;
