@@ -5,7 +5,7 @@ use warnings;
 package Sub::HandlesVia::HandlerLibrary::String;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.015';
+our $VERSION   = '0.017';
 
 use Sub::HandlesVia::HandlerLibrary;
 our @ISA = 'Sub::HandlesVia::HandlerLibrary';
@@ -13,7 +13,14 @@ our @ISA = 'Sub::HandlesVia::HandlerLibrary';
 use Sub::HandlesVia::Handler qw( handler );
 use Types::Standard qw( Optional Str CodeRef RegexpRef Int Any Item Defined );
 
-our @METHODS = qw( set get inc append prepend replace match chop chomp clear reset length substr replace_globally );
+our @METHODS = qw(
+	set get inc append prepend chop chomp clear reset
+	length substr replace replace_globally uc lc fc
+	starts_with   ends_with   contains   match   cmp  eq  ne  gt  lt  ge  le
+	starts_with_i ends_with_i contains_i match_i cmpi eqi nei gti lti gei lei
+);
+
+my $fold = ( $] >= 5.016 ) ? 'CORE::fc' : 'lc';
 
 sub _type_inspector {
 	my ($me, $type) = @_;
@@ -108,6 +115,69 @@ sub match {
 		template  => '$GET =~ /$ARG/',
 }
 
+sub match_i {
+	handler
+		name      => 'String:match_i',
+		args      => 1,
+		signature => [ Str|RegexpRef ],
+		usage     => '$regexp',
+		template  => '$GET =~ /$ARG/i',
+}
+
+sub starts_with {
+	handler
+		name      => 'String:starts_with',
+		args      => 1,
+		signature => [ Str ],
+		usage     => '$head',
+		template  => 'substr($GET, 0, length $ARG) eq $ARG',
+}
+
+sub starts_with_i {
+	handler
+		name      => 'String:starts_with_i',
+		args      => 1,
+		signature => [ Str ],
+		usage     => '$head',
+		template  => sprintf( '%s(substr($GET, 0, length $ARG)) eq %s($ARG)', $fold, $fold ),
+}
+
+sub ends_with {
+	handler
+		name      => 'String:ends_with',
+		args      => 1,
+		signature => [ Str ],
+		usage     => '$tail',
+		template  => 'substr($GET, -length $ARG) eq $ARG',
+}
+
+sub ends_with_i {
+	handler
+		name      => 'String:ends_with_i',
+		args      => 1,
+		signature => [ Str ],
+		usage     => '$tail',
+		template  => sprintf( '%s(substr($GET, -length $ARG)) eq %s($ARG)', $fold, $fold ),
+}
+
+sub contains {
+	handler
+		name      => 'String:contains',
+		args      => 1,
+		signature => [ Str ],
+		usage     => '$str',
+		template  => 'index($GET, $ARG) != -1',
+}
+
+sub contains_i {
+	handler
+		name      => 'String:contains_i',
+		args      => 1,
+		signature => [ Str ],
+		usage     => '$tail',
+		template  => sprintf( 'index(%s($GET), %s($ARG)) != -1', $fold, $fold ),
+}
+
 sub chop {
 	handler
 		name      => 'String:chop',
@@ -160,4 +230,36 @@ sub substr {
 		lvalue_template  => 'if (#ARG==1) { substr($GET, $ARG[1]) } elsif (#ARG==2) { substr($GET, $ARG[1], $ARG[2]) } elsif (#ARG==3) { substr($GET, $ARG[1], $ARG[2], $ARG[3]) } ',
 }
 
+for my $comparison ( qw/ cmp eq ne lt gt le ge / ) {
+	no strict 'refs';
+
+	*$comparison = sub {
+		handler
+			name      => "String:$comparison",
+			args      => 1,
+			signature => [Str],
+			usage     => '$str',
+			template  => "\$GET $comparison \$ARG",
+	};
+
+	*{ $comparison . 'i' } = sub {
+		handler
+			name      => "String:$comparison" . 'i',
+			args      => 1,
+			signature => [Str],
+			usage     => '$str',
+			template  => "$fold(\$GET) $comparison $fold(\$ARG)",
+	};
+}
+
+for my $mutation ( qw/ uc fc lc / ) {
+	no strict 'refs';
+	*$mutation = sub {
+		handler
+			name      => "String:$mutation",
+			args      => 0,
+			template  => "$mutation(\$GET)",
+	};
+}
+
 1;
